//#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <SDL/SDL.h>
#include "isola.h"
#include "fct.h"
#include "jeu.h"
#include "ia.h"
#include "menu.h"


// ****************************************************************************
// ********************************** Main ************************************
// ****************************************************************************
int main (int argc, char *argv[])
{
	JEU jeu;					// Donnes principales du jeu
	Uint32 flags;				// Paramtres pour l'affichage (fentre ou plein cran)
	int i;
	
	srand ((unsigned) time (NULL));	// Initialise le gnrateur de nbs alatoires
	flags = SDL_SWSURFACE | SDL_FULLSCREEN;	// Plein cran par dfaut
	
	// Lit les options passes en argument au programme
	for (i = 1; i < argc; i ++)
	{
		if (!strcmp (argv[i], "-h") || !strcmp (argv[i], "--help"))		// Affiche une aide
		{	printf ("********** Do'SSi Zo'la **********\nby Cyril CLEMENT & Gaelle DAIREAUX\n");
			printf ("-h : this help\n-f : fullscreen\n-w : windowed\n");
			exit (0);
		}
		else if (!strcmp (argv[i], "-f"))	// Mode plein cran
			flags = SDL_SWSURFACE | SDL_FULLSCREEN;
		else if (!strcmp (argv[i], "-w"))	// Mode fentre
			flags = SDL_SWSURFACE;
		else
		{	fprintf (stderr, "%s not allowed.\n", argv[i]);
			exit (1);
		}
	}	
	
	// Initialise SDL
	if (SDL_Init (SDL_INIT_VIDEO) < 0)
	{	fprintf (stderr, "Impossible d'initialiser SDL (%s)\n", SDL_GetError());
		exit (1);
	}
	// Librera les ressources utilises par SDL en quittant
	atexit (SDL_Quit);
	
	// Initialise l'affichage en plein cran ou en fentre en 1024x768x32
	jeu.ecran = SDL_SetVideoMode (1024, 768, 32, flags);
	if (!jeu.ecran)
	{	fprintf (stderr, "Impossible de definir le mode 1024*768*32 (%s)\n", SDL_GetError());
		exit (1);
	}
	// Dfinit le titre de la fentre
	SDL_WM_SetCaption ("Do'SSi Zo'la", "Do'SSi Zo'la");
	
	// Cre un back buffer (une copie de sauvegarde de l'cran en mmoire)
	if (!(jeu.back = SDL_DisplayFormat (jeu.ecran)))
	{ 	fprintf (stderr, "Impossible de crer un back buffer (%s)\n", SDL_GetError ());
		SDL_FreeSurface (jeu.back);
		exit (1);
	}
	
	// Prpare la police de caractre
	if (!(jeu.police1.img = SDL_LoadBMP (IMG_POLICE1))) ImageErreur (IMG_POLICE1);
	if (!(jeu.police2.img = SDL_LoadBMP (IMG_POLICE2))) ImageErreur (IMG_POLICE2);
	if (!(jeu.police3.img = SDL_LoadBMP (IMG_POLICE3))) ImageErreur (IMG_POLICE3);
	SDL_SetColorKey (jeu.police1.img, SDL_SRCCOLORKEY, SDL_MapRGB (jeu.police1.img->format, 255, 0, 255));
	SDL_SetColorKey (jeu.police2.img, SDL_SRCCOLORKEY, SDL_MapRGB (jeu.police2.img->format, 255, 0, 255));
	SDL_SetColorKey (jeu.police3.img, SDL_SRCCOLORKEY, SDL_MapRGB (jeu.police3.img->format, 255, 0, 255));
	jeu.police1.rect.x = jeu.police2.rect.x = jeu.police3.rect.x = 0;
	jeu.police1.rect.y = jeu.police2.rect.y = jeu.police3.rect.y = 0;
	jeu.police1.rect.w = jeu.police2.rect.w = jeu.police3.rect.w = jeu.police1.img->w / 37;		// Il y a 37 caracteres dans la police
	jeu.police1.rect.h = jeu.police2.rect.h = jeu.police3.rect.h = jeu.police1.img->h;
	
	// Paramtres par dfaut
	jeu.J1ROUGE = DFT_J1ROUGE;
	jeu.J1TYPE = DFT_J1TYPE;
	jeu.J2TYPE = DFT_J2TYPE;
	jeu.J1NIVO = DFT_J1NIVO;
	jeu.J2NIVO = DFT_J2NIVO;
	jeu.INTEMP = DFT_INTEMP;
	jeu.DOUBLE_DEPLACE  = DFT_DOUBLE_DEPLACE;
	jeu.DOUBLE_BOULEFEU = DFT_DOUBLE_BOULEFEU;
	jeu.XGRILLE = DFT_XGRILLE;
	jeu.YGRILLE = DFT_YGRILLE;
	FPS = DFT_FPS;
	
	while (1)
	{
		// Lance le menu de choix des options du jeu si la fonction retourne oui, le prog quitte
		if (Menu (&jeu)) break;
		
		// Lance une partie
		Jeu (&jeu);
	}
	
	printf ("\nIf you have fun with this game, do not forget to rate it at :\n\thttp://happypenguin.org/show?Do'SSi%%20Zo'la\n\n");
	
	SDL_FreeSurface (jeu.back);
	SDL_FreeSurface (jeu.police1.img);
	SDL_FreeSurface (jeu.police2.img);
	SDL_FreeSurface (jeu.police3.img);
	
	return 0;
}